### 0.13.0 {small}`2025-08-06`

```{rubric} Features
```
* Add support for aggregate operations on CSC matrices, Fortran-ordered arrays, and Dask with sparse CSR and dense matrices {pr}`395` {smaller}`S Dicks`
* Adds dask support for `tl.score_genes` & `tl.score_genes_cell_cycle` {pr}`408` {smaller}`S Dicks`
* Adds dask support for `tl.rank_genes_groups_logreg` {pr}`413` {smaller}`S Dicks`
* Updates {mod}`rapids_singlecell.dcg` to work with `Decoupler 2.0.0` {pr}`418` {smaller}`S Dicks`

```{rubric} Performance
```
* speed up `pp.harmony_integrate` for smaller datasets {pr}`421` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* Fixes a bug for `_get_mean_var` with dask chunk sizes {pr}`408` {smaller}`S Dicks`

```{rubric} Misc
```
* Removes `wsum` {pr}`418` {smaller}`S Dicks`
* Update `decoupler-GPU` demo notebook {pr}`419` {smaller}`S Dicks`
